==> fpm_0.53.orig.tar.gz: fpm-0.53/src/callbacks.h <==
/* FIGARO'S PASSWORD MANAGER (FPM)
 * Copyright (C) 2000 John Conneely
 * 
 * FPM is open source / free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * FPM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 * callbacks.h
 */

#include <gnome.h>

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_app_safe_destroy_event              (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_app_safe_destroy                    (GtkObject       *object,
                                        gpointer         user_data);

void
on_button_ok_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cancel_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_new_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_clist_main_select_row               (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_edit_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_app_safe_delete_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_clist_main_button_press_event       (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_clist_main_button_release_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_save1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_exit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_save_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_edit_passitem_delete_event   (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_edit_passitem_destroy        (GtkObject       *object,
                                        gpointer         user_data);

void
on_dialog_edit_passitem_show           (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_togglebutton_showpass_toggled       (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button_jump_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_pass_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_user_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_password_ok_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_password_cancel_clicked      (GtkButton       *button,
                                        gpointer         user_data);


void
on_gpw_toggled                         (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_button_generate_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_gen_generate_now_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_gen_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_gen_cancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_password_activate             (GtkEditable     *editable,
                                        gpointer         user_data);


void
on_button_cpw_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cpw_cancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);


void
on_copy_pass_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_copy_user_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item_password_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_prefs_ok_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_prefs_cancel_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_item_delete_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_change_cat_clicked           (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_prefs_destroy_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_prefs_destroy                (GtkObject       *object,
                                        gpointer         user_data);

==> fpm-0.59.tar.gz: fpm-0.59/src/callbacks.h <==
/* FIGARO'S PASSWORD MANAGER (FPM)
 * Copyright (C) 2000 John Conneely
 * 
 * FPM is open source / free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * FPM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 * callbacks.h
 */

#include <gnome.h>

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_app_safe_destroy_event              (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_app_safe_destroy                    (GtkObject       *object,
                                        gpointer         user_data);

void
on_button_ok_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cancel_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_new_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_clist_main_select_row               (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_edit_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_app_safe_delete_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_clist_main_button_press_event       (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_clist_main_button_release_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_save1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_exit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_save_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_edit_passitem_delete_event   (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_edit_passitem_destroy        (GtkObject       *object,
                                        gpointer         user_data);

void
on_dialog_edit_passitem_show           (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_togglebutton_showpass_toggled       (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button_jump_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_pass_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_user_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_password_ok_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_password_cancel_clicked      (GtkButton       *button,
                                        gpointer         user_data);


void
on_gpw_toggled                         (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_button_generate_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_gen_generate_now_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_gen_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_gen_cancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_password_activate             (GtkEditable     *editable,
                                        gpointer         user_data);


void
on_button_cpw_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cpw_cancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);


void
on_copy_pass_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_copy_user_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item_password_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_prefs_ok_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_prefs_cancel_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_item_delete_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_change_cat_clicked           (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_prefs_destroy_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_prefs_destroy                (GtkObject       *object,
                                        gpointer         user_data);

void
on_export1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_import_passwords1_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_import_ok_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_import_cancel_clicked        (GtkButton       *button,
                                        gpointer         user_data);
